@@ -14,7 +14,6 @@
 
 from collections import defaultdict
 import logging
-import six
 import threading
 
 from cassandra.cluster import Cluster, _ConfigMode, _NOT_SET, NoHostAvailable, UserTypeDoesNotExist, ConsistencyLevel
@@ -324,7 +323,7 @@ def setup(
     :param int consistency: The global default :class:`~.ConsistencyLevel` - default is the same as :attr:`.Session.default_consistency_level`
     :param bool lazy_connect: True if should not connect until first use
     :param bool retry_connect: True if we should retry to connect even if there was a connection failure initially
-    :param \*\*kwargs: Pass-through keyword arguments for :class:`cassandra.cluster.Cluster`
+    :param kwargs: Pass-through keyword arguments for :class:`cassandra.cluster.Cluster`
     """
 
     from cassandra.cqlengine import models
@@ -346,7 +345,7 @@ def execute(query, params=None, consistency_level=None, timeout=NOT_SET, connect
     elif isinstance(query, BaseCQLStatement):
         params = query.get_context()
         query = SimpleStatement(str(query), consistency_level=consistency_level, fetch_size=query.fetch_size)
-    elif isinstance(query, six.string_types):
+    elif isinstance(query, str):
         query = SimpleStatement(query, consistency_level=consistency_level)
     log.debug(format_log_context('Query: {}, Params: {}'.format(query.query_string, params), connection=connection))
 
