@@ -16,7 +16,6 @@ import copy
 from datetime import datetime, timedelta
 from functools import partial
 import time
-import six
 from warnings import warn
 
 from cassandra.query import SimpleStatement, BatchType as CBatchType, BatchStatement
@@ -103,29 +102,29 @@ class AbstractQueryableColumn(UnicodeMixin):
 
         used where you'd typically want to use python's `in` operator
         """
-        return WhereClause(six.text_type(self), InOperator(), item)
+        return WhereClause(str(self), InOperator(), item)
 
     def contains_(self, item):
         """
         Returns a CONTAINS operator
         """
-        return WhereClause(six.text_type(self), ContainsOperator(), item)
+        return WhereClause(str(self), ContainsOperator(), item)
 
 
     def __eq__(self, other):
-        return WhereClause(six.text_type(self), EqualsOperator(), self._to_database(other))
+        return WhereClause(str(self), EqualsOperator(), self._to_database(other))
 
     def __gt__(self, other):
-        return WhereClause(six.text_type(self), GreaterThanOperator(), self._to_database(other))
+        return WhereClause(str(self), GreaterThanOperator(), self._to_database(other))
 
     def __ge__(self, other):
-        return WhereClause(six.text_type(self), GreaterThanOrEqualOperator(), self._to_database(other))
+        return WhereClause(str(self), GreaterThanOrEqualOperator(), self._to_database(other))
 
     def __lt__(self, other):
-        return WhereClause(six.text_type(self), LessThanOperator(), self._to_database(other))
+        return WhereClause(str(self), LessThanOperator(), self._to_database(other))
 
     def __le__(self, other):
-        return WhereClause(six.text_type(self), LessThanOrEqualOperator(), self._to_database(other))
+        return WhereClause(str(self), LessThanOrEqualOperator(), self._to_database(other))
 
 
 class BatchType(object):
@@ -206,8 +205,8 @@ class BatchQuery(object):
 
         :param fn: Callable object
         :type fn: callable
-        :param \*args: Positional arguments to be passed to the callback at the time of execution
-        :param \*\*kwargs: Named arguments to be passed to the callback at the time of execution
+        :param args: Positional arguments to be passed to the callback at the time of execution
+        :param kwargs: Named arguments to be passed to the callback at the time of execution
         """
         if not callable(fn):
             raise ValueError("Value for argument 'fn' is {0} and is not a callable object.".format(type(fn)))
@@ -231,7 +230,7 @@ class BatchQuery(object):
         opener = 'BEGIN ' + (str(batch_type) + ' ' if batch_type else '') + ' BATCH'
         if self.timestamp:
 
-            if isinstance(self.timestamp, six.integer_types):
+            if isinstance(self.timestamp, int):
                 ts = self.timestamp
             elif isinstance(self.timestamp, (datetime, timedelta)):
                 ts = self.timestamp
@@ -277,8 +276,8 @@ class ContextQuery(object):
     A Context manager to allow a Model to switch context easily. Presently, the context only
     specifies a keyspace for model IO.
 
-    :param \*args: One or more models. A model should be a class type, not an instance.
-    :param \*\*kwargs: (optional) Context parameters: can be *keyspace* or *connection*
+    :param args: One or more models. A model should be a class type, not an instance.
+    :param kwargs: (optional) Context parameters: can be *keyspace* or *connection*
 
     For example:
 
@@ -286,15 +285,15 @@ class ContextQuery(object):
 
             with ContextQuery(Automobile, keyspace='test2') as A:
                 A.objects.create(manufacturer='honda', year=2008, model='civic')
-                print len(A.objects.all())  # 1 result
+                print(len(A.objects.all()))  # 1 result
 
             with ContextQuery(Automobile, keyspace='test4') as A:
-                print len(A.objects.all())  # 0 result
+                print(len(A.objects.all()))  # 0 result
 
             # Multiple models
             with ContextQuery(Automobile, Automobile2, connection='cluster2') as (A, A2):
-                print len(A.objects.all())
-                print len(A2.objects.all())
+                print(len(A.objects.all()))
+                print(len(A2.objects.all()))
 
     """
 
@@ -407,7 +406,7 @@ class AbstractQuerySet(object):
             return result
 
     def __unicode__(self):
-        return six.text_type(self._select_query())
+        return str(self._select_query())
 
     def __str__(self):
         return str(self.__unicode__())
@@ -604,7 +603,7 @@ class AbstractQuerySet(object):
 
     def first(self):
         try:
-            return six.next(iter(self))
+            return next(iter(self))
         except StopIteration:
             return None
 
@@ -809,11 +808,11 @@ class AbstractQuerySet(object):
 
             print("Normal")
             for comment in Comment.objects(photo_id=u):
-                print comment.comment_id
+                print(comment.comment_id)
 
             print("Reversed")
             for comment in Comment.objects(photo_id=u).order_by("-comment_id"):
-                print comment.comment_id
+                print(comment.comment_id)
         """
         if len(colnames) == 0:
             clone = copy.deepcopy(self)
@@ -901,7 +900,7 @@ class AbstractQuerySet(object):
         if v is None:
             v = 0
 
-        if not isinstance(v, six.integer_types):
+        if not isinstance(v, int):
             raise TypeError
         if v == self._limit:
             return self
@@ -925,7 +924,7 @@ class AbstractQuerySet(object):
                 print(user)
         """
 
-        if not isinstance(v, six.integer_types):
+        if not isinstance(v, int):
             raise TypeError
         if v == self._fetch_size:
             return self
