@@ -50,11 +50,6 @@ MAX_LONG = 9223372036854775807
 MIN_LONG = -9223372036854775808
 ZERO_LONG = 0
 
-if sys.version_info < (3, 0):
-    MAX_LONG = long(MAX_LONG)
-    MIN_LONG = long(MIN_LONG)
-    ZERO_LONG = long(ZERO_LONG)
-
 MAKE_STRICT = "schema.config().option('graph.schema_mode').set('production')"
 MAKE_NON_STRICT = "schema.config().option('graph.schema_mode').set('development')"
 ALLOW_SCANS = "schema.config().option('graph.allow_scan').set('true')"
