@@ -13,7 +13,7 @@
 # limitations under the License.
 import unittest
 
-import mock
+from unittest import mock
 import logging
 from packaging.version import Version
 from cassandra.cqlengine.connection import get_session, get_cluster
@@ -254,7 +254,7 @@ class TablePropertiesTests(BaseCassEngTestCase):
 
         table_options = management._get_table_metadata(ModelWithTableProperties).options
 
-        self.assertDictContainsSubset(ModelWithTableProperties.__options__, table_options)
+        self.assertLessEqual(ModelWithTableProperties.__options__.items(), table_options.items())
 
     def test_bogus_option_update(self):
         sync_table(ModelWithTableProperties)
