@@ -12,8 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import unittest
-
-import mock
+from unittest import mock
 from uuid import uuid4
 
 from cassandra.cqlengine import columns
