@@ -13,6 +13,7 @@
 # limitations under the License.
 
 import unittest
+from unittest.mock import patch
 
 
 from tests.unit.io.utils import TimerTestMixin
@@ -23,8 +24,6 @@ try:
 except ImportError:
     GeventConnection = None  # noqa
 
-from mock import patch
-
 
 skip_condition = GeventConnection is None or EVENT_LOOP_MANAGER != "gevent"
 @unittest.skipIf(skip_condition, "Skipping the gevent tests because it's not installed")
