@@ -13,20 +13,20 @@
 # limitations under the License.
 import unittest
 
-from mock import patch, Mock
+from unittest.mock import patch, Mock
 import weakref
 import socket
 
-from tests import is_monkey_patched
-from tests.unit.io.utils import ReactorTestMixin, TimerTestMixin, noop_if_monkey_patched
-
-
+from cassandra import DependencyException
 try:
     from cassandra.io.libevreactor import _cleanup as libev__cleanup
     from cassandra.io.libevreactor import LibevConnection
-except ImportError:
+except DependencyException:
     LibevConnection = None  # noqa
 
+from tests import is_monkey_patched
+from tests.unit.io.utils import ReactorTestMixin, TimerTestMixin, noop_if_monkey_patched
+
 
 class LibevConnectionTest(ReactorTestMixin, unittest.TestCase):
 
