@@ -27,7 +27,7 @@ import random
 from functools import wraps
 from itertools import cycle
 from io import BytesIO
-from mock import Mock
+from unittest.mock import Mock
 
 import errno
 import logging
@@ -181,7 +181,7 @@ class TimerTestMixin(object):
         timer = self.create_timer(timeout, callback.invoke)
         timer.cancel()
         # Release context allow for timer thread to run.
-        time.sleep(.2)
+        time.sleep(timeout * 2)
         timer_manager = self._timers
         # Assert that the cancellation was honored
         self.assertFalse(timer_manager._queue)
