@@ -11,13 +11,12 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from cassandra.query import named_tuple_factory, dict_factory, tuple_factory
 
 import unittest
-
-from mock import Mock, PropertyMock, patch
+from unittest.mock import Mock, PropertyMock, patch
 
 from cassandra.cluster import ResultSet
+from cassandra.query import named_tuple_factory, dict_factory, tuple_factory
 
 
 class ResultSetTests(unittest.TestCase):
